**************************************************
* State do file to recode Yale CCES survey items *
* Gregory Huber, January 2007                    *
**************************************************

set memory 500m
set more off
use data\AJPS_YaleSample.dta

**************************************************
* Recode Common survey Pre-items items           *
**************************************************

*pid3
recode pid3 (1=1) (2=-1) (3=0) (4=0), gen(pre_pid3)

*pid5 (. values said they were dems on pid3)
recode pid7 (1=2) (2=1) (3=1) (4=0) (5=-1) (6=-1) (7=-2) (8=0) (.=1), gen(pre_pid5)

*pid7 (. values said they were dems on pid3)
recode pid7 (1=3) (2=2) (3=1) (4=0) (5=-1) (6=-2) (7=-3) (8=0) (.=1), gen(pre_pid7)

*female
recode gender (1=0) (2=1), gen(pre_female)

*race (white, hispanic, black)
recode race (1=1) (*=0), gen(pre_white)
recode race (3=1) (*=0), gen(pre_hispanic)
recode race (2=1) (*=0), gen(pre_black)

*age
gen age=2006-birthyr
gen age2=age^2

*union status
recode unionmem (1=1) (*=0), gen(pre_unionmem)

*income
recode income (98=.) (99=.), gen(pre_income)
replace pre_income=(pre_income-1)/14
gen pre_incomedkna=0
replace pre_incomedkna=. if pre_income==.
replace pre_incomedkna=1 if pre_income==1

*education
gen pre_educ=educ-1

**************************************************
* Recode Pre-survey items                        *
**************************************************

*holiday gift spending amounts
*first clean out $ and commas and other junk
replace pr_gifts=subinstr(pr_gifts,"dollars","",.) 
replace pr_gifts=subinstr(pr_gifts,"nothing","0",.) 
replace pr_gifts=subinstr(pr_gifts,"$","",.)
replace pr_gifts=subinstr(pr_gifts,",","",.)
replace pr_gifts=subinstr(pr_gifts,"o","0",.) 
replace pr_gifts=subinstr(pr_gifts,"O","0",.) 
replace pr_gifts=trim(pr_gifts)
gen pre_holidayspend=real(trim(pr_gifts))
*specific recodings for textual/range responses
replace pre_holidayspend=400 if pr_gifts=="300-500"
replace pre_holidayspend=625 if pr_gifts=="500-750"
replace pre_holidayspend=350 if pr_gifts=="3-400"
replace pre_holidayspend=500 if pr_gifts=="500 0r less"
l pre_holidayspend pr_gifts if pre_holidayspend ==.

*vacation spending amounts
replace pr_vacat=subinstr(pr_vacat,"dollars","",.) 
replace pr_vacat=subinstr(pr_vacat,"nothing","0",.) 
replace pr_vacat=subinstr(pr_vacat,"none","0",.)
replace pr_vacat=subinstr(pr_vacat,"NONE","0",.)
replace pr_vacat=subinstr(pr_vacat,"no vacation","0",.) 
replace pr_vacat=subinstr(pr_vacat,"zero","0",.)
replace pr_vacat=subinstr(pr_vacat,"$","",.)
replace pr_vacat=subinstr(pr_vacat,",","",.)
replace pr_vacat=subinstr(pr_vacat,"o","0",.) 
replace pr_vacat=subinstr(pr_vacat,"O","0",.) 
replace pr_vacat=trim(pr_vacat)
gen pre_vacationspend=real(trim(pr_vacat))
*specific recodings for textual/range responses
replace pre_vacationspend=650 if pr_vacat=="600.00 t0 700.00"
replace pre_vacationspend=2000 if pr_vacat=="2k"
replace pre_vacationspend=1000 if pr_vacat=="1k"
replace pre_vacationspend=1000 if pr_vacat=="1.000.00"
replace pre_vacationspend=0 if pr_vacat=="-0-"
replace pre_vacationspend=200 if pr_vacat=="#200"
replace pre_vacationspend=500 if pr_vacat=="@500"
replace pre_vacationspend=650 if pr_vacat=="5-800"
l pre_vacationspend pr_vacat if pre_vacationspend ==.

*happiness
recode pr_happy (1 = 3) (2 = 2) (3 =1) (4 = 0), gen(pre_happy)

*expectations about household income getting better
recode pr_hhinc (1=2) (2=1) (3=0) (4=-1) (5=-2), gen(pre_hhincomeforecast)

*expectations about national economy getting better
recode pr_natpr (1=2) (2=1) (3=0) (4=-1) (5=-2), gen(pre_nationaleconforecast)

*expectations about state economy getting better
recode pr_state (1=2) (2=1) (3=0) (4=-1) (5=-2), gen(pre_stateeconforecast)

**************************************************
* Recode Post-survey items                       *
**************************************************

*holiday gift spending amounts
*first clean out $ and commas and other junk
replace pt_gifts=subinstr(pt_gifts,"dollars","",.) 
replace pt_gifts=subinstr(pt_gifts,"nothing","0",.) 
replace pt_gifts=subinstr(pt_gifts,"$","",.)
replace pt_gifts=subinstr(pt_gifts,",","",.)
replace pt_gifts=subinstr(pt_gifts,"o","0",.) 
replace pt_gifts=subinstr(pt_gifts,"O","0",.) 
replace pt_gifts=trim(pt_gifts)
gen post_holidayspend=real(trim(pt_gifts))

*vacation spending amounts
replace pt_vacat="2000" if caseid==949378
replace pt_vacat=subinstr(pt_vacat,"dollars","",.) 
replace pt_vacat=subinstr(pt_vacat,"nothing","0",.) 
replace pt_vacat=subinstr(pt_vacat,"none","0",.)
replace pt_vacat=subinstr(pt_vacat,"NONE","0",.)
replace pt_vacat=subinstr(pt_vacat,"no vacation","0",.) 
replace pt_vacat=subinstr(pt_vacat,"zero","0",.)
replace pt_vacat=subinstr(pt_vacat,"$","",.)
replace pt_vacat=subinstr(pt_vacat,",","",.)
replace pt_vacat=subinstr(pt_vacat,"o","0",.) 
replace pt_vacat=subinstr(pt_vacat,"O","0",.) 
replace pt_vacat=trim(pt_vacat)
gen post_vacationspend=real(trim(pt_vacat))

*happiness
recode pt_happy (1 = 3) (2 = 2) (3 =1) (4 = 0), gen(post_happy)

*expectations about household income getting better
recode pt_hhinc (1=2) (2=1) (3=0) (4=-1) (5=-2), gen(post_hhincomeforecast)

*expectations about national economy getting better
recode pt_natpr (1=2) (2=1) (3=0) (4=-1) (5=-2), gen(post_nationaleconforecast)

*expectations about state economy getting better
recode pt_state (1=2) (2=1) (3=0) (4=-1) (5=-2), gen(post_stateeconforecast)

sort state

joinby state using "data\2006GovElectionForecastsandOutcomes.dta"

order caseid state weight pid3 pid7 fips postdisp 

save data\yaledata_recoded.dta, replace
